@@ -76,8 +76,12 @@ CONFIG_SCHEMA = {
 
 
 class Config(pydantic.BaseModel):
-    keyvalues: typing.Dict[str, jsonlog_cli.pattern.KeyValuePattern] = {}
-    templates: typing.Dict[str, jsonlog_cli.pattern.TemplatePattern] = {}
+    keyvalues: typing.Dict[str, jsonlog_cli.pattern.KeyValuePattern] = pydantic.Field(
+        default_factory=dict
+    )
+    templates: typing.Dict[str, jsonlog_cli.pattern.TemplatePattern] = pydantic.Field(
+        default_factory=dict
+    )
 
     @classmethod
     def load(cls, filename: str) -> "Config":
